"""
Django Admin MCP - Expose Django admin models to MCP clients
"""

from django_admin_mcp.mixin import MCPAdminMixin

__version__ = "0.3.0"
__author__ = "Barbaros Goren"
__email__ = "gorenbarbaros@gmail.com"
__all__ = [
    "MCPAdminMixin",
]
