"""
Django app configuration for django-admin-mcp
"""

from django.apps import AppConfig


class DjangoAdminMcpConfig(AppConfig):
    """Configuration for django-admin-mcp app."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "django_admin_mcp"
    verbose_name = "Django Admin MCP"
